@@ -2,8 +2,6 @@ import socket
 
 from plogger import logger
 
-logger = logger('SocketClient')
-
 
 class SocketClient:
     """Create socket and establish connect to service using tuple host+port"""
@@ -24,7 +22,7 @@ class SocketClient:
 
         self.host = host
         self.port = port
-        self.logger = logger
+        self.logger = logger(self.__class__.__name__)
         self.logger.disabled = not logger_enabled
         self.connection_timeout = connection_timeout
 
@@ -39,6 +37,10 @@ class SocketClient:
                 self.logger.error(f'{self.host}:{self.port} is unavailable within 7 sec. {err}')
                 raise err
 
+    def __getattr__(self, attr):
+        self.logger.warning(f'No such attribute ({attr}) error. Perhaps, object is not initialized.')
+        raise AttributeError(f'{self.__class__.__name__}() does not have specific attribute "{attr}"')
+
     def __str__(self):
         return str(self._socket_response())
 
@@ -50,11 +52,11 @@ class SocketClient:
         """
         return socket.create_connection((self.host, self.port), timeout=timeout)
 
-    def is_socket_available(
-            self, port: int = 0,
-            host: str = None,
-            timeout: int = 5,
-            logger_enabled: bool = True) -> bool:
+    def is_socket_available(self,
+                            port: int = 0,
+                            host: str = None,
+                            timeout: int = 5,
+                            logger_enabled: bool = True) -> bool:
         """Check remote socket is available.
 
         Port 0 used by default. Used port from construct is not specified.
@@ -62,6 +64,7 @@ class SocketClient:
         :param host:
         :param port:
         :param timeout:
+        :param logger_enabled:
         """
 
         host_ = host if host else self.host
@@ -95,22 +98,23 @@ class SocketClient:
             timer += 1
 
             if timer > timeout:
-                raise TimeoutError(f'The service was not started within {timeout} seconds.')
+                error_msg = f'The service was not started within {timeout} seconds.'
+                self.logger.error(error_msg)
+                raise TimeoutError(error_msg)
         return status
 
     def _greeting(self):
         """Works only for the first connection in all project"""
         return self._socket_response()
 
-    def send_command(self, cmd=''):
+    def send_command(self, cmd: str = ''):
         command = self._encode_command(cmd)
 
-        self.logger.info(f'[{self.host}] {cmd}')
+        self.logger.info(f'[{self.host} -->] {cmd}')
 
         try:
             self.client.send(command)
             response = self._socket_response()
-
             return response
         except AttributeError as err:
             self.logger.error(f'[{self.host}] {err}')
@@ -120,7 +124,7 @@ class SocketClient:
 
         data = self.client.recv(65536).decode()
         response = data.strip().split('\n')
-        self.logger.info(f'[{self.host} RESPONSE] {response}')
+        self.logger.info(f'[{self.host} <--] {response}')
 
         return response
 
